@@ -42,20 +42,24 @@ fn main() -> Result<()> {
         bean.bean_nickname = buff.to_string();
     }
     bean.bean_nickname = buff.to_string();
-
-    // Get name from database if exists
     bean.get(db_file).unwrap();
 
     // Create new roast instance
     let mut new_roast = &mut Roast::new(bean.to_owned());
 
-    println!("Bean name you entered: {}", bean.bean_nickname);
+    // Remove
+    println!("bean id: {}", bean.id);
+
+    println!(
+        "Bean name you entered: {}",
+        new_roast.bean_name.bean_nickname
+    );
     String::clear(&mut buff);
 
     // Get starting weight from user
     println!("Enter starting weight: ");
     stdin.read_line(&mut buff)?;
-    new_roast.starting_weight = buff.trim().parse::<u32>().unwrap();
+    new_roast.starting_weight = buff.trim().parse::<f32>().unwrap();
     println!("Starting weight: {}", new_roast.starting_weight);
     String::clear(&mut buff);
 
@@ -89,6 +93,8 @@ fn main() -> Result<()> {
     println!("Enter \"s\" if going to second crack. Press any other key to end roast");
     stdin.read_line(buff)?;
     if buff.eq(&mut "s\n") {
+        new_roast.second_crack_start = Some(time_now());
+        new_roast.second_crack_finish = Some(time_now());
         String::clear(&mut buff);
         println!("Press ENTER when second crack starts ");
         io::stdin().read_line(buff)?;
@@ -107,10 +113,15 @@ fn main() -> Result<()> {
             stdin.read_line(buff)?;
             check_buff(buff.to_string());
             handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
+            new_roast.insert(db_file).unwrap();
+        } else {
+            handle_roast_event(RoastEvent::SecondCrackEnd(), new_roast.to_owned())?;
+            new_roast.insert(db_file).unwrap();
+            handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
         }
     } else {
-        handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
         new_roast.insert(db_file).unwrap();
+        handle_roast_event(RoastEvent::EndRoast(), new_roast.to_owned())?;
     }
 
     Ok(())
